#
# This is the server logic of a Shiny web application. You can run the
# application by clicking 'Run App' above.
#
# Find out more about building applications with Shiny here:
#
#    http://shiny.rstudio.com/
#

library(shiny)
library(shinydashboard)
library(htmltools)
library(markdown)
library(visNetwork)
library(DT)
library(plotly)
library(shinyBS)
library(magrittr)
library(colorspace)

source("src/renderHTMLTable.R")

shinyServer(function(session, input, output) {

    outputTable <- read.csv("data/all_renku_releases.csv")
    outputTable$notesOutput <- sapply(outputTable$notes, shiny::markdown)
    outputTable$notes <- NULL
    repos <- unique(outputTable$repo)

    output$allReleases <- renderUI({
        mainPanel(
            DT::renderDT(datatable(outputTable,
                                   rownames = FALSE,
                                   escape = FALSE) %>%
                             formatStyle(
                                 'repo',
                                 target = 'row',
                                 backgroundColor = styleEqual(repos,
                                                              lighten(rainbow_hcl(length(repos)),
                                                                      amount = 0.6))
                             )
                         )
        )
    })

    for (repo in repos) {
        output[[repo]] <- renderHTMLTable(repo)
    }

})
