args <- commandArgs(trailingOnly = TRUE)

library(curl)
library(jsonlite)

# Default repositories available
allRepos <- c("renku", "renku-gateway", "renku-graph", "renku-notebooks",
           "renku-jupyter", "renku-python", "renku-ui",
           "renku-project-template", "renkulab-docker")

# Default argument for 'all' repos:
chosenRepos <- args
if (chosenRepos == "all" || length(chosenRepos) == 0) {
  # No repo specified, do all of them
  repos <- allRepos
} else {
  repos <- intersect(allRepos, args)
}

# Default to 100 releases (all of them)
getData <- function(repo, number = 100) {
  get <- curl_fetch_memory(paste0("https://api.github.com/repos/SwissDataScienceCenter/", repo, "/releases?per_page=", number))
  releases <- fromJSON(rawToChar(get$content))
  output <- data.frame(version = releases$tag_name,
                     name = releases$name,
                     author = releases$author$login, 
                     date = substr(releases$published_at, 1, 10), 
                     notes = releases$body)
  # Add name to table
  output$repo <- repo
  write.csv(output, 
            file.path("data", paste0("releases_", repo, ".csv")),
            row.names = FALSE)
}

invisible(lapply(repos, getData))
